package com.ztmap.project.zhny.lotuscbcjl.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.lotuscbcjl.mapper.TLotusCbcjlMapper;
import com.ztmap.project.zhny.lotuscbcjl.domain.TLotusCbcjl;
import com.ztmap.project.zhny.lotuscbcjl.service.ITLotusCbcjlService;
import com.ztmap.common.utils.text.Convert;

/**
 * 抄采集率Service业务层处理
 * 
 * @author ztmap
 * @date 2023-11-16
 */
@Service
public class TLotusCbcjlServiceImpl implements ITLotusCbcjlService 
{
    @Autowired
    private TLotusCbcjlMapper tLotusCbcjlMapper;

    /**
     * 查询抄采集率
     * 
     * @param id 抄采集率ID
     * @return 抄采集率
     */
    @Override
    public TLotusCbcjl selectTLotusCbcjlById(Long id)
    {
        return tLotusCbcjlMapper.selectTLotusCbcjlById(id);
    }

    /**
     * 查询抄采集率列表
     * 
     * @param tLotusCbcjl 抄采集率
     * @return 抄采集率
     */
    @Override
    public List<TLotusCbcjl> selectTLotusCbcjlList(TLotusCbcjl tLotusCbcjl)
    {
        return tLotusCbcjlMapper.selectTLotusCbcjlList(tLotusCbcjl);
    }

    /**
     * 新增抄采集率
     * 
     * @param tLotusCbcjl 抄采集率
     * @return 结果
     */
    @Override
    public int insertTLotusCbcjl(TLotusCbcjl tLotusCbcjl)
    {
        return tLotusCbcjlMapper.insertTLotusCbcjl(tLotusCbcjl);
    }

    /**
     * 修改抄采集率
     * 
     * @param tLotusCbcjl 抄采集率
     * @return 结果
     */
    @Override
    public int updateTLotusCbcjl(TLotusCbcjl tLotusCbcjl)
    {
        return tLotusCbcjlMapper.updateTLotusCbcjl(tLotusCbcjl);
    }

    /**
     * 删除抄采集率对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTLotusCbcjlByIds(String ids)
    {
        return tLotusCbcjlMapper.deleteTLotusCbcjlByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除抄采集率信息
     * 
     * @param id 抄采集率ID
     * @return 结果
     */
    @Override
    public int deleteTLotusCbcjlById(Long id)
    {
        return tLotusCbcjlMapper.deleteTLotusCbcjlById(id);
    }
}
